# rocket needs to be imported anywhere you want to use the GUI
import rocket

# make the engine accessable
import Pengyne

# get a copy of the current engine
engine = Pengyne.GetEngine()

# add the Media directory to load resources from
engine.Resources().AddArchive("Media")

# create the render window (title, width, height, fullscreen)
engine.SetupDisplay("Pengyne Tutorial", 800, 480, False)

# switch to 2d rendering mode as a default. This can be changed at any time.
engine.GetCamera().SetupView2D()

engine.SetActionKey("ESCAPE", "Quit")

# a GameState must be created and set to command the engine what to render and handle input
class TutorialMenuState(Pengyne.GameState):
	def __init__(self):
		# standard python subclass...
		Pengyne.GameState.__init__(self)
		# Open the menu
		self.menu = engine.GetGUIContext().LoadDocument("TutorialMenu.rml")
		# Don't forget to show it
		self.menu.Show(True)
	
	# Nothing to be rendered here, it is just to show the menu
	def Render(self):
		pass
	
	# This is called from the TutorialMenu.rml file when a button is clicked
	def ChangeTutorial(self, name):
		newstate = None
		if name == "Sprites":
			import sprites
			newstate = sprites.SpritesState()
			
		if name == "Voxel Box":
			import voxel_box
			newstate = voxel_box.VoxelBoxState()
		if name == "Point Field":
			import pointfield
			newstate = pointfield.PointFieldState()
		if name == "Tiled Map":
			import tiled
			newstate = tiled.MapViewer()
			
		if newstate != None:
			self.menu.Close()
			self.menu = None
			engine.ActivateGameState(newstate)
		
	# This catches when the window is closed
	def OnClose(self):
		engine.Quit()
	
	def OnClick(self, event):
		pass

	def OnKeyDown(self, action):
		if action == "Quit":
			engine.Quit()
			
	def OnKeyUp(self, action):
		pass
		
# Set the engine with the inital state
engine.ActivateGameState(TutorialMenuState())

# run enters the game loop, acting on the state set above
engine.Run()