import Pengyne
import rocket
engine = Pengyne.GetEngine()

class PointFieldState(Pengyne.GameState):
	def __init__(self):
		Pengyne.GameState.__init__(self)
		
		# switch to 3d mode
		engine.GetCamera().SetupView3D(90.0, .1, 500.0)
		
		# create the shader
		self.shader = Pengyne.Shader()
		# both vertex and fragment shaders are needed
		self.shader.VertexFromFile("PointField.vert")
		self.shader.FragmentFromFile("PointField.frag")
		# dont forget to link
		self.shader.Link()
		
		# create a buffer to hold the points
		self.pbo = Pengyne.VertexBuffer()
		self.pbo.SetMode("Points")
		
		# add position to the vertex declaration
		self.pbo.AddMember("Position", Pengyne.GL.FLOAT, 3)
		
		start = -25
		end = 25
		dim = end - start
		
		# preallocate the buffer, faster than appending one at a time
		buff = range(dim*dim*dim*3)
		
		off = 0
		size = 10
		
		# generate the positions
		for x in range(start, end):
			for y in range(start, end):
				for z in range(start, end):
					buff[off] = x * size
					off += 1
					buff[off] = y * size
					off += 1
					buff[off] = z * size
					off += 1
	
		# add the buffer data to the VertexBuffer
		self.pbo.Add(buff)
		
		# BasicRenderOp has the bare minimum to render, a vertex buffer and shader
		self.op = Pengyne.BasicRenderOp()
		self.op.SetVertices(self.pbo)
		self.op.SetShader(self.shader)
		
		# move the camera to make it a little moreinteresting
		#engine.GetCamera().Move([.00,0.00, -200])
		
		
	def Render(self):
		# rotate the field around the viewer
		self.op.Rotate([1, 0, 0], 5)
		self.op.Rotate([0, 1, 0], 3)
		self.op.Rotate([0, 0, 1], 1)
		#draw the field
		engine.Render(self.op)
		
	def OnClose(self):
		engine.Quit()

	def OnClick(self, event):
		pass

	def OnKeyDown(self, action):
		if action == "Quit":
			engine.Quit()
			
	def OnKeyUp(self, action):
		pass